psychopy_ext.exp.SVG
====================

.. currentmodule:: psychopy_ext.exp

.. autoclass:: SVG

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SVG.__init__
      ~SVG.color2attr
      ~SVG.color2rgb255
      ~SVG.get_pos
      ~SVG.get_size
      ~SVG.open
      ~SVG.save
      ~SVG.write
   
   

   
   
   